@@ -40,6 +40,10 @@ private slots:
     void aboutClicked();
     void gameEnded();
     void enableSaving();
+    void showStatistics();
+
+protected:
+    void closeEvent(QCloseEvent *event);
 
 private:
     MainWindow(QWidget *parent = 0);
@@ -51,8 +55,10 @@ private:
     QAction *importAction_;
     QAction *aboutAction_;
     QAction *saveAction_;
+    QAction *statisticsAction_;
 
     QMenu *menu_;
+    QMenu *helpMenu_;
 
     SettingsDialog *settingsDialog_;
 };
